@@ -934,7 +934,8 @@ def send_response(sock, response, address):
 
 class SNMPServer:
     DEFAULT_LISTEN_HOST = '0.0.0.0'
-    DEFAULT_LISTEN_PORT = 1234
+    DEFAULT_LISTEN_PORT = 0
+    DELAY_BEFORE_REPLY = 0
 
     def __init__(self, host, port):
         self.host = host
@@ -946,6 +947,8 @@ class SNMPServer:
 
     def __enter__(self):
         self.sock.bind((self.host, self.port))
+        if self.port == 0:
+            self.port = self.sock.getsockname()[1]
         logger.info('SNMP server listening on {}:{}'.format(self.host, self.port))
         return self
 
@@ -972,6 +975,7 @@ class SNMPServer:
                 raise ValueError(f'Request OID ({_id}) was not expected')
 
             response = generate_response(request_result, self.expected_messages)
+            time.sleep(self.DELAY_BEFORE_REPLY)
             send_response(self.sock, response, address)
 
     def expect_request(self, request_id, reply_with, populate_parent=True):
